==> rsunlight_0.4.2.tar.gz: rsunlight/R/defunct.R <==
#' This function is defunct.
#' @export
#' @rdname ie_politicians-defunct
#' @keywords internal
ie_politicians <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_organizations-defunct
#' @keywords internal
ie_organizations <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_industries-defunct
#' @keywords internal
ie_industries <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_individuals-defunct
#' @keywords internal
ie_individuals <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_lobbying-defunct
#' @keywords internal
ie_lobbying <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_grants-defunct
#' @keywords internal
ie_grants <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_contracts-defunct
#' @keywords internal
ie_contracts <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_faca-defunct
#' @keywords internal
ie_faca <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_epa-defunct
#' @keywords internal
ie_epa <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_entities-defunct
#' @keywords internal
ie_entities <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_earmarks-defunct
#' @keywords internal
ie_earmarks <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}
#' This function is defunct.
#' @export
#' @rdname ie_contr_bundled-defunct
#' @keywords internal
ie_contr_bundled <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_contr-defunct
#' @keywords internal
ie_contr <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_sectors-defunct
#' @keywords internal
ie_sectors <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' Defunct functions in rsunlight
#'
#' \itemize{
#'  \item \code{\link{ie_politicians}}: Removed. See \code{Influence Explorer} below
#'  \item \code{\link{ie_organizations}}: Removed. See \code{Influence Explorer} below
#'  \item \code{\link{ie_industries}}: Removed. See \code{Influence Explorer} below
#'  \item \code{\link{ie_individuals}}: Removed. See \code{Influence Explorer} below
#'  \item \code{\link{ie_lobbying}}: Removed. See \code{Influence Explorer} below
#'  \item \code{\link{ie_grants}}: Removed. See \code{Influence Explorer} below
#'  \item \code{\link{ie_contracts}}: Removed. See \code{Influence Explorer} below
#'  \item \code{\link{ie_faca}}: Removed. See \code{Influence Explorer} below
#'  \item \code{\link{ie_epa}}: Removed. See \code{Influence Explorer} below
#'  \item \code{\link{ie_entities}}: Removed. See \code{Influence Explorer} below
#'  \item \code{\link{ie_earmarks}}: Removed. See \code{Influence Explorer} below
#'  \item \code{\link{ie_contr_bundled}}: Removed. See \code{Influence Explorer} below
#'  \item \code{\link{ie_contr}}: Removed. See \code{Influence Explorer} below
#' }
#'
#' @section Influence Explorer:
#' The Influence Explorer API is now defunct/gone.
#'
#' @name rsunlight-defunct
NULL

==> rsunlight_0.7.0.tar.gz: rsunlight/R/defunct.R <==
#' This function is defunct.
#' @export
#' @rdname ie_politicians-defunct
#' @keywords internal
ie_politicians <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_organizations-defunct
#' @keywords internal
ie_organizations <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_industries-defunct
#' @keywords internal
ie_industries <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_individuals-defunct
#' @keywords internal
ie_individuals <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_lobbying-defunct
#' @keywords internal
ie_lobbying <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_grants-defunct
#' @keywords internal
ie_grants <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_contracts-defunct
#' @keywords internal
ie_contracts <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_faca-defunct
#' @keywords internal
ie_faca <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_epa-defunct
#' @keywords internal
ie_epa <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_entities-defunct
#' @keywords internal
ie_entities <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_earmarks-defunct
#' @keywords internal
ie_earmarks <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}
#' This function is defunct.
#' @export
#' @rdname ie_contr_bundled-defunct
#' @keywords internal
ie_contr_bundled <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_contr-defunct
#' @keywords internal
ie_contr <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname ie_sectors-defunct
#' @keywords internal
ie_sectors <- function(...){
  .Defunct(msg = "Sunlight Foundation Transparency/Influence Explorer API defunct as of January 2016")
}

#' This function is defunct.
#' @export
#' @rdname cg_votes-defunct
#' @keywords internal
cg_votes <- function(...){
  .Defunct(msg = "See ?votes for the new functions")
}

#' Defunct functions in rsunlight
#'
#' - `ie_politicians`: Removed. See `Influence Explorer` below
#' - `ie_organizations`: Removed. See `Influence Explorer` below
#' - `ie_industries`: Removed. See `Influence Explorer` below
#' - `ie_individuals`: Removed. See `Influence Explorer` below
#' - `ie_lobbying`: Removed. See `Influence Explorer` below
#' - `ie_grants`: Removed. See `Influence Explorer` below
#' - `ie_contracts`: Removed. See `Influence Explorer` below
#' - `ie_faca`: Removed. See `Influence Explorer` below
#' - `ie_epa`: Removed. See `Influence Explorer` below
#' - `ie_entities`: Removed. See `Influence Explorer` below
#' - `ie_earmarks`: Removed. See `Influence Explorer` below
#' - `ie_contr_bundled`: Removed. See `Influence Explorer` below
#' - `ie_contr`: Removed. See `Influence Explorer` below
#'
#' @section Influence Explorer:
#' The Influence Explorer API is now defunct/gone.
#'
#' @name rsunlight-defunct
NULL
